==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TimeoutPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Policy to set request timeouts
 * @property connectionTimeoutInSeconds Timeout, in seconds, for a request to initiate a connection
 * @property responseTimeoutInSeconds Timeout, in seconds, for a request to respond
 */
public data class TimeoutPolicyArgs(
    public val connectionTimeoutInSeconds: Output<Int>? = null,
    public val responseTimeoutInSeconds: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs =
        com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs.builder()
            .connectionTimeoutInSeconds(connectionTimeoutInSeconds?.applyValue({ args0 -> args0 }))
            .responseTimeoutInSeconds(responseTimeoutInSeconds?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TimeoutPolicyArgs].
 */
@PulumiTagMarker
public class TimeoutPolicyArgsBuilder internal constructor() {
    private var connectionTimeoutInSeconds: Output<Int>? = null

    private var responseTimeoutInSeconds: Output<Int>? = null

    /**
     * @param value Timeout, in seconds, for a request to initiate a connection
     */
    @JvmName("pqqhdbtcptojmumc")
    public suspend fun connectionTimeoutInSeconds(`value`: Output<Int>) {
        this.connectionTimeoutInSeconds = value
    }

    /**
     * @param value Timeout, in seconds, for a request to respond
     */
    @JvmName("qpqesfdeyfdqrqls")
    public suspend fun responseTimeoutInSeconds(`value`: Output<Int>) {
        this.responseTimeoutInSeconds = value
    }

    /**
     * @param value Timeout, in seconds, for a request to initiate a connection
     */
    @JvmName("lajtspaujmiobpow")
    public suspend fun connectionTimeoutInSeconds(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionTimeoutInSeconds = mapped
    }

    /**
     * @param value Timeout, in seconds, for a request to respond
     */
    @JvmName("hgokuvycuxvofshn")
    public suspend fun responseTimeoutInSeconds(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseTimeoutInSeconds = mapped
    }

    internal fun build(): TimeoutPolicyArgs = TimeoutPolicyArgs(
        connectionTimeoutInSeconds = connectionTimeoutInSeconds,
        responseTimeoutInSeconds = responseTimeoutInSeconds,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/TimeoutPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Policy to set request timeouts
 * @property connectionTimeoutInSeconds Timeout, in seconds, for a request to initiate a connection
 * @property responseTimeoutInSeconds Timeout, in seconds, for a request to respond
 */
public data class TimeoutPolicyArgs(
    public val connectionTimeoutInSeconds: Output<Int>? = null,
    public val responseTimeoutInSeconds: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs =
        com.pulumi.azurenative.app.inputs.TimeoutPolicyArgs.builder()
            .connectionTimeoutInSeconds(connectionTimeoutInSeconds?.applyValue({ args0 -> args0 }))
            .responseTimeoutInSeconds(responseTimeoutInSeconds?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TimeoutPolicyArgs].
 */
@PulumiTagMarker
public class TimeoutPolicyArgsBuilder internal constructor() {
    private var connectionTimeoutInSeconds: Output<Int>? = null

    private var responseTimeoutInSeconds: Output<Int>? = null

    /**
     * @param value Timeout, in seconds, for a request to initiate a connection
     */
    @JvmName("yykequaecsadtssv")
    public suspend fun connectionTimeoutInSeconds(`value`: Output<Int>) {
        this.connectionTimeoutInSeconds = value
    }

    /**
     * @param value Timeout, in seconds, for a request to respond
     */
    @JvmName("qiweraykebwdeket")
    public suspend fun responseTimeoutInSeconds(`value`: Output<Int>) {
        this.responseTimeoutInSeconds = value
    }

    /**
     * @param value Timeout, in seconds, for a request to initiate a connection
     */
    @JvmName("fopeqvlrptbnytvd")
    public suspend fun connectionTimeoutInSeconds(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionTimeoutInSeconds = mapped
    }

    /**
     * @param value Timeout, in seconds, for a request to respond
     */
    @JvmName("tyftdvjxvkvfhuiu")
    public suspend fun responseTimeoutInSeconds(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.responseTimeoutInSeconds = mapped
    }

    internal fun build(): TimeoutPolicyArgs = TimeoutPolicyArgs(
        connectionTimeoutInSeconds = connectionTimeoutInSeconds,
        responseTimeoutInSeconds = responseTimeoutInSeconds,
    )
}
